@@ -3,7 +3,7 @@ import tempfile
 from sys import stdout 
 from time import sleep
 
-from processing import Process
+from multiprocessing import Process
 
 import lib.messageboard as mb
 from lib.pyvnc2swf import vnc2swf
@@ -17,11 +17,13 @@ class Castro:
                  filename = "castro-video.swf",
                  host     = "localhost",
                  display  = 0,
+                 framerate = 12,
                  clipping = None,
                  passwd   = os.path.join(os.path.expanduser("~"), ".vnc", "passwd")):
         s.filename = filename
         s.host = host
         s.display = display
+        s.framerate = framerate
         s.clipping = clipping
         s.passwd = passwd
         s.init()
@@ -37,6 +39,11 @@ class Castro:
             args.insert(4, '-P')
             args.insert(5, s.passwd)
 
+        # If framerate is specified, insert it into args
+        if s.framerate:
+            args.insert(4, '-r')
+            args.insert(5, s.framerate)
+
         # If clipping is specified, insert it into args
         if s.clipping:
             args.insert(4, '-C')
